/*
Copyright (c) 2013-2014 Gustav Hartvigsson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

#include "utils.h"
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>

char * s_string_new (const char * s) {
  char * ret_val = malloc (strlen (s) + 1);
  strcpy (ret_val, s);
  free ((char *) s);
  return ret_val;
}

char * s_string_new_fmt (const char * format, ...) {
  char * ret_val = malloc (strlen (format) + 1);
  strcpy (ret_val, format);
  free ((char *) format);
  return ret_val;
}

char * s_string_new_with_len (const char * s, size_t len) {
  char * ret_val = malloc (len + 1);
  strncpy (ret_val, s, len);
  free ((char *) s);
  return ret_val;
}

void s_print (const char * format, ...) {
  va_list args;
  va_start (args, format);
  fprintf (stdout, (char *) format, args);
  va_end (args);
}

void s_err_print (char * format, ...) {
  va_list args;
  va_start (args, format);
  fprintf (stderr,RED "[ERR] ");
  fprintf (stderr, format, args);
  fprintf (stderr, RESET);
  va_end (args);
}

#if DEBUG
  void s_dbg_print (char * format, ...) {
    va_list args;
    va_start (args, format);
    fprintf (stderr, YELLOW "[DEBUG] ");
    fprintf (stderr, format, args);
    fprintf (stderr, RESET);
    va_end (args);
  }
#else
  void s_dbg_print (char * format, ...) {
    /* do nothing */
  }
#endif
